@@ -35,12 +35,11 @@
 #include <kconfigbase.h>
 #include <kconfiggroup.h>
 
-#include <boost/mem_fn.hpp>
 #include <algorithm>
 #include <QDebug>
+
 using namespace Kleo;
 using namespace GpgME;
-using namespace boost;
 
 //
 //
