@@ -31,9 +31,9 @@
 
 #include "test_keygen.h"
 
-#include "libkleo/keylistjob.h"
-#include "libkleo/keygenerationjob.h"
-#include "libkleo/cryptobackendfactory.h"
+#include <qgpgme/keylistjob.h>
+#include <qgpgme/keygenerationjob.h>
+#include <qgpgme/protocol.h>
 #include "ui/progressdialog.h"
 
 #include <gpgme++/keygenerationresult.h>
@@ -47,7 +47,6 @@
 #include <QLabel>
 #include <QGridLayout>
 
-#include <assert.h>
 #include <QApplication>
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -120,22 +119,21 @@ void KeyGenerator::slotStartKeyGeneration()
         }
     params += "</GnupgKeyParms>\n";
 
-    const Kleo::CryptoBackend::Protocol *proto = 0;
+    const QGpgME::Protocol *proto = 0;
     if (protocol) {
-        proto = !strcmp(protocol, "openpgp") ? Kleo::CryptoBackendFactory::instance()->openpgp() : Kleo::CryptoBackendFactory::instance()->smime();
+        proto = !strcmp(protocol, "openpgp") ? QGpgME::openpgp() : QGpgME::smime();
     }
     if (!proto) {
-        proto = Kleo::CryptoBackendFactory::instance()->smime();
+        proto = QGpgME::smime();
     }
-    assert(proto);
+    Q_ASSERT(proto);
 
     qDebug() << "Using protocol" << proto->name();
 
-    Kleo::KeyGenerationJob *job = proto->keyGenerationJob();
-    assert(job);
+    QGpgME::KeyGenerationJob *job = proto->keyGenerationJob();
+    Q_ASSERT(job);
 
-    connect(job, SIGNAL(result(GpgME::KeyGenerationResult,QByteArray)),
-            SLOT(slotResult(GpgME::KeyGenerationResult,QByteArray)));
+    connect(job, &QGpgME::KeyGenerationJob::result, this, &KeyGenerator::slotResult);
 
     const GpgME::Error err = job->start(params);
     if (err) {
